# codeberg-pages-deploy

A drone plugin to deploy to codeberg pages. Basically takes a folder and pushes it to the "pages" branch in the same repo.

## Example usage

```yaml
on:
  push:
    branches:
      - main

jobs:
  build:
    runs-on: ubuntu-latest
    steps:
      - uses: actions/checkout@v3

      - name: Setup Hugo
        uses: https://github.com/peaceiris/actions-hugo.git@v2
        with:
          hugo-version: "latest"
          extended: true

      - name: Build
        run: |
          hugo --minify

      - name: Setup Go
        uses: actions/setup-go@v3
        with:
          go-version: "1.21"

      - name: Deploy
        uses: https://itsblue.dev/actions/codeberg-pages-deploy@v1
        with:
          folder: ./public
```

Note: you have to either use an image which includes go or set it up before running this action. See [Creating Go Actions](https://blog.gitea.com/creating-go-actions/).

## Options

| parameter          | description                                                  | default                                       |
| -------------      | ------------------------------------------------------------ | --------------------------------------------- |
| folder             | The folder to deploy from                                    |                                               |
| remote_folder      | The folder to deploy to in the remote repo                   | `/`                                           |
| ssh_key            | The private ssh key to use if pushing to an ssh remote       | empty                                         |
| git_remote         | A custom git remote to push to                               | the current repo                              |
| git_branch         | The branch to push to                                        | pages                                         |
| git_name           | The name to use for the commit                               | `[BOT] pages deployer`                        |
| git_email          | The email to use for the commit                              | `noreply@pages.bot`                           |
| commit_message     | The commit message                                           | `Update pages  🚀`                             |
| token              | The token/password to use if pushing to a custom http remote | the gitea-supplied token (aka `GITHUB_TOKEN`) |
| username           | The username to use if pushing to a custom http remote       | the actor (aka `GITHUB_ACTOR`)                |
| force              | Force commit and overwrite all previous commits              | `false`                                       |